# onshape_client
A Python client for using the Onshape REST API. 

## Getting started
1. get an API key from the [Onshape Dev Portal.](https://dev-portal.onshape.com/)

2. copy them to your own version of [`onshape_clients/.onshape_client_config_EXAMPLE.yaml`](/.onshape_client_config_EXAMPLE.yaml) in the spots for `YOUR SECRET KEY` and `YOUR ACCESS KEY`

3. try running any of the scripts within [`onshape_clients/python/onshape_client/example_programs`](/python/test/example_programs)

## More guidance
Another good place to see intended use and supported functionality is within [`onshape_clients/python/tests`](/python/test)